<?php

	/* 
		Plugin Name: Force SSL everywhere
		Plugin URI: http://wpplugz.is-leet.com
		Description: A simple plugin that forces SSL on all pages when logged in.
		Version: 1.0
		Author: Bostjan Cigan
		Author URI: http://bostjan.gets-it.net
		License: GPL v2
	*/ 

	add_action('init', 'force_ssl_everywhere_force_ssl_when_admin');
	add_action('auth_redirect', 'force_ssl_everywhere_check_force_ssl');
	add_action('wp_logout', 'force_ssl_everywhere_clear'); // Adding action to logout (clearing cookies etc.)
	add_action('wp_login', 'force_ssl_everywhere_add_auth', 10, 2);

	function force_ssl_everywhere_add_auth($user_login, $user) {
	
		$user_data = get_user_meta($user->ID, 'force_ssl_everywhere_id', true);

		$red_url = get_admin_url();
		
		if(!isset($_COOKIE['wp_force_id'])) {
			$force_id = force_ssl_everywhere_random_string(32);
			$id = force_ssl_everywhere_random_string(32);
			if(!is_array($user_data)) {
				$user_data = array();
				$user_data[$id] = $force_id;
				update_user_meta($user->ID, 'force_ssl_everywhere_id', $user_data);
			}
			else {
				$user_data[$id] = $force_id;
				update_user_meta($user->ID, 'force_ssl_everywhere_id', $user_data);
			}
			$red_url = plugin_dir_url(__FILE__).'cookie.php?force_id='.$force_id.'&id='.$id;
		}
		
		header("Location: $red_url");
		exit;
		
	}
	
	function force_ssl_everywhere_clear() {
		global $current_user;
		get_currentuserinfo();
		if(isset($_COOKIE['wp_force_id'])) {
			$user_data = get_user_meta($current_user->ID, 'force_ssl_everywhere_id', true);
			unset($user_data[$_COOKIE['wp_force_id']]);
			update_user_meta($current_user->ID, 'force_ssl_everywhere_id', $user_data);
		}
		setcookie("wp_force_ssl", "", time()-3600*24, COOKIEPATH, COOKIE_DOMAIN, true);
		setcookie("wp_force_id", "", time()-3600*24, COOKIEPATH, COOKIE_DOMAIN, true);
	}
	
	function force_ssl_everywhere_check_force_ssl() {	
		
		global $current_user;
		get_currentuserinfo();

		$user_data = get_user_meta($current_user->ID, 'force_ssl_everywhere_id', true);
		
		if(isset($_COOKIE['wp_force_ssl']) && is_user_logged_in() && is_ssl() && isset($_COOKIE['wp_force_id'])) {
			if(strcmp($user_data[$_COOKIE['wp_force_id']], $_COOKIE['wp_force_ssl']) == 0) {
				return true;
			}
			else {
				wp_logout();
			}
		}
		else {
			wp_logout();
		}

	}
	
	// Generate a random string	
	function force_ssl_everywhere_random_string($length) {
	    
		$characters = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz';
    	$string = '';
    	for($i=0; $i<$length; $i++) {
	        $string .= $characters[mt_rand(0, strlen($characters)-1)];
    	}
    
		return $string;

	}

	function force_ssl_everywhere_force_ssl_when_admin() {
	
		if(is_ssl()) {
			return;
		}
		else {
			if(is_user_logged_in()) {
				wp_redirect(
					'https://' . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'] 
				);
				exit;
			
			}
		}
	}
	
?>